==> syncfusion_flutter_pdf-18.1.46-beta.tar.gz: lib/src/pdf/implementation/graphics/fonts/pdf_font.dart <==
part of pdf;

/// Defines a particular format for text, including font face, size, and style attributes.
abstract class PdfFont implements _IPdfWrapper {
  //Constants
  static const double _characterSizeMultiplier = 0.001;
  static const List<String> _standardFontNames = <String>[
    'Helvetica',
    'courier',
    'TimesRoman',
    'Symbol',
    'ZapfDingbats'
  ];
  static const List<String> _standardCjkFontNames = <String>[
    'HanyangSystemsGothicMedium',
    'HanyangSystemsShinMyeongJoMedium',
    'HeiseiKakuGothicW5',
    'HeiseiMinchoW3',
    'MonotypeHeiMedium',
    'MonotypeSungLight',
    'SinoTypeSongLight'
  ];

  //Fields
  /// Size of the font.
  double _size;

  /// Style of the font.
  PdfFontStyle get style => _style;

  /// Metrics of the font.
  _PdfFontMetrics _metrics;

  /// PDf primitive of the font.
  _IPdfPrimitive _fontInternals;

  /// Number format of [PdfFontStyle]
  int _fontStyle = 0;

  PdfFontStyle _style = PdfFontStyle.regular;

  //Properties
  ///Gets the font name.
  String get name => _metrics.name;

  ///Gets the font size.
  double get size => _size;

  /// Gets the height of the font in points.
  double get height => _metrics._getHeight(null);

  //ignore:unused_element
  bool get _isUnderline =>
      _fontStyle & _getPdfFontStyle(PdfFontStyle.underline) > 0;
  //ignore:unused_element
  bool get _isStrikeout =>
      _fontStyle & _getPdfFontStyle(PdfFontStyle.strikethrough) > 0;

  //Public methods
  /// Measures a string by using this font.
  ///
  /// ```dart
  /// //Create a new PDF document.
  /// PdfDocument document = PdfDocument();
  /// //Add a page to the document.
  /// PdfPage page = document.pages.add();
  /// //Create PDF graphics for the page.
  /// PdfGraphics graphics = page.graphics;
  /// //Create a new PDF font instance.
  /// PdfFont font = PdfStandardFont(PdfFontFamily.helvetica, 12);
  /// String text = "Hello World!";
  /// //Measure the text.
  /// Size size = font.measureString(text);
  /// //Draw string to PDF page.
  /// graphics.drawString(text, font,
  ///     brush: PdfBrushes.black,
  ///     bounds: Rect.fromLTWH(0, 0, size.width, size.height));
  /// //Saves the document.
  /// List<int> bytes = doc.save();
  /// //Dispose the document.
  /// doc.dispose();
  /// ```
  Size measureString(String text, {Size layoutArea, PdfStringFormat format}) {
    ArgumentError.checkNotNull(text);
    layoutArea ??= const Size(0, 0);
    final _PdfStringLayouter layouter = _PdfStringLayouter();
    final _PdfStringLayoutResult result = layouter._layout(text, this, format,
        width: layoutArea.width, height: layoutArea.height);
    return result._size.size;
  }

  //Implementation
  /// Initializes a new instance of the [PdfFont] class with font size and style.
  void _initialize(double size,
      {PdfFontStyle style, List<PdfFontStyle> multiStyle}) {
    _setSize(size);
    _setStyle(style, multiStyle);
  }

  ///Sets the style.
  void _setStyle(PdfFontStyle style, List<PdfFontStyle> multiStyle) {
    if (style != null) {
      _style = style;
      _fontStyle = _getPdfFontStyle(style);
    }
    if (multiStyle != null && multiStyle.isNotEmpty) {
      for (int i = 0; i < multiStyle.length; i++) {
        _fontStyle |= _getPdfFontStyle(multiStyle[i]);
      }
    } else if (style == null) {
      _style = PdfFontStyle.regular;
    }
  }

  ///Sets the font size.
  void _setSize(double value) {
    if (_metrics != null) {
      _metrics.size = value;
    }
    _size = value;
  }

  /// Gets the value for PdfFontStyle.
  static int _getPdfFontStyle(PdfFontStyle value) {
    switch (value) {
      case PdfFontStyle.regular:
        return 0;
      case PdfFontStyle.bold:
        return 1;
      case PdfFontStyle.italic:
        return 2;
      case PdfFontStyle.underline:
        return 4;
      case PdfFontStyle.strikethrough:
        return 8;
      default:
        return null;
    }
  }

  /// Returns width of the line.
  double _getLineWidth(String line, PdfStringFormat format);

  /// Applies settings to the default line width.
  double _applyFormatSettings(
      String line, PdfStringFormat format, double width) {
    double realWidth = width;
    if (format != null && width > 0) {
      if (format.characterSpacing != 0) {
        realWidth += (line.length - 1) * format.characterSpacing;
      }
      if (format.wordSpacing != 0) {
        final int whitespacesCount =
            _StringTokenizer._getCharacterCount(line, _StringTokenizer._spaces);
        realWidth += whitespacesCount * format.wordSpacing;
      }
    }
    return realWidth;
  }
}

==> syncfusion_flutter_pdf-18.4.46-beta.tar.gz: lib/src/pdf/implementation/graphics/fonts/pdf_font.dart <==
part of pdf;

/// Defines a particular format for text, including font face, size,
/// and style attributes.
abstract class PdfFont implements _IPdfWrapper {
  //Constants
  static const double _characterSizeMultiplier = 0.001;
  static const List<String> _standardFontNames = <String>[
    'Helvetica',
    'courier',
    'TimesRoman',
    'Symbol',
    'ZapfDingbats'
  ];
  static const List<String> _standardCjkFontNames = <String>[
    'HanyangSystemsGothicMedium',
    'HanyangSystemsShinMyeongJoMedium',
    'HeiseiKakuGothicW5',
    'HeiseiMinchoW3',
    'MonotypeHeiMedium',
    'MonotypeSungLight',
    'SinoTypeSongLight'
  ];

  //Fields
  /// Size of the font.
  double _size;

  /// Style of the font.
  PdfFontStyle get style => _style;

  /// Metrics of the font.
  _PdfFontMetrics _metrics;

  /// PDf primitive of the font.
  _IPdfPrimitive _fontInternals;

  /// Number format of [PdfFontStyle]
  int _fontStyle = 0;

  PdfFontStyle _style = PdfFontStyle.regular;

  //Properties
  ///Gets the font name.
  String get name => _metrics.name;

  ///Gets the font size.
  double get size => _size;

  /// Gets the height of the font in points.
  double get height => _metrics._getHeight(null);

  //ignore:unused_element
  bool get _isUnderline =>
      _fontStyle & _getPdfFontStyle(PdfFontStyle.underline) > 0;
  //ignore:unused_element
  bool get _isStrikeout =>
      _fontStyle & _getPdfFontStyle(PdfFontStyle.strikethrough) > 0;

  //Public methods
  /// Measures a string by using this font.
  ///
  /// ```dart
  /// //Create a new PDF document.
  /// PdfDocument document = PdfDocument();
  /// //Add a page to the document.
  /// PdfPage page = document.pages.add();
  /// //Create PDF graphics for the page.
  /// PdfGraphics graphics = page.graphics;
  /// //Create a new PDF font instance.
  /// PdfFont font = PdfStandardFont(PdfFontFamily.helvetica, 12);
  /// String text = "Hello World!";
  /// //Measure the text.
  /// Size size = font.measureString(text);
  /// //Draw string to PDF page.
  /// graphics.drawString(text, font,
  ///     brush: PdfBrushes.black,
  ///     bounds: Rect.fromLTWH(0, 0, size.width, size.height));
  /// //Saves the document.
  /// List<int> bytes = doc.save();
  /// //Dispose the document.
  /// doc.dispose();
  /// ```
  Size measureString(String text, {Size layoutArea, PdfStringFormat format}) {
    ArgumentError.checkNotNull(text);
    layoutArea ??= const Size(0, 0);
    final _PdfStringLayouter layouter = _PdfStringLayouter();
    final _PdfStringLayoutResult result = layouter._layout(text, this, format,
        width: layoutArea.width, height: layoutArea.height);
    return result._size.size;
  }

  //Implementation
  /// Initializes a new instance of the [PdfFont] class
  /// with font size and style.
  void _initialize(double size,
      {PdfFontStyle style, List<PdfFontStyle> multiStyle}) {
    _setSize(size);
    _setStyle(style, multiStyle);
  }

  ///Sets the style.
  void _setStyle(PdfFontStyle style, List<PdfFontStyle> multiStyle) {
    if (style != null) {
      _style = style;
      _fontStyle = _getPdfFontStyle(style);
    }
    if (multiStyle != null && multiStyle.isNotEmpty) {
      for (int i = 0; i < multiStyle.length; i++) {
        _fontStyle |= _getPdfFontStyle(multiStyle[i]);
      }
    } else if (style == null) {
      _style = PdfFontStyle.regular;
    }
  }

  ///Sets the font size.
  void _setSize(double value) {
    if (_metrics != null) {
      _metrics.size = value;
    }
    _size = value;
  }

  /// Gets the value for PdfFontStyle.
  static int _getPdfFontStyle(PdfFontStyle value) {
    switch (value) {
      case PdfFontStyle.regular:
        return 0;
      case PdfFontStyle.bold:
        return 1;
      case PdfFontStyle.italic:
        return 2;
      case PdfFontStyle.underline:
        return 4;
      case PdfFontStyle.strikethrough:
        return 8;
      default:
        return null;
    }
  }

  /// Returns width of the line.
  double _getLineWidth(String line, PdfStringFormat format);

  /// Applies settings to the default line width.
  double _applyFormatSettings(
      String line, PdfStringFormat format, double width) {
    double realWidth = width;
    if (format != null && width > 0) {
      if (format.characterSpacing != 0) {
        realWidth += (line.length - 1) * format.characterSpacing;
      }
      if (format.wordSpacing != 0) {
        final int whitespacesCount =
            _StringTokenizer._getCharacterCount(line, _StringTokenizer._spaces);
        realWidth += whitespacesCount * format.wordSpacing;
      }
    }
    return realWidth;
  }
}
